@@ -19,6 +19,8 @@
 #'
 #' @return [ggplot2::ggplot()] object.
 #'
+#' @template section_theme
+#'
 #' @references
 #' `r format_bib("precrec")`
 #'
@@ -43,17 +45,34 @@ autoplot.PredictionClassif = function(object, type = "stacked", measure = NULL,
       tab = melt(fortify(object)[, c("truth", "response")],
         measure.vars = c("truth", "response"))
       ggplot(tab, aes_string(fill = "value", x = "variable")) +
-        geom_bar(...) +
+        geom_bar(width = 0.5, ...) +
         geom_label(stat = "count", aes_string(label = "..count.."),
-          position = position_stack(vjust = 0.5))
+          position = position_stack(vjust = 0.5), colour = "white") +
+        xlab("Feature") +
+        ylab("Count") +
+        apply_theme(list(
+          scale_fill_viridis_d("Feature", end = 0.8),
+          theme_mlr3()
+        ))
     },
 
     "roc" = {
-      plot_precrec(object, curvetype = "ROC", ...)
+      plot_precrec(object, curvetype = "ROC", ...) +
+        apply_theme(list(
+          scale_color_viridis_d(),
+          theme_mlr3(legend = "none"),
+          theme(plot.title = element_blank())
+        ))
+
     },
 
     "prc" = {
-      plot_precrec(object, curvetype = "PRC", ...)
+      plot_precrec(object, curvetype = "PRC", ...) +
+        apply_theme(list(
+          scale_color_viridis_d(),
+          theme_mlr3(legend = "none"),
+          theme(plot.title = element_blank())
+        ))
     },
 
     "threshold" = {
@@ -62,9 +81,13 @@ autoplot.PredictionClassif = function(object, type = "stacked", measure = NULL,
       tab = data.table(prob = seq(from = 0, to = 1, by = 0.01))
       tab$score = map_dbl(tab$prob, function(p) pred$set_threshold(p)$score(measure))
       ggplot(tab, aes_string(x = "prob", y = "score")) +
-        geom_line() +
+        geom_line(color = apply_theme(viridis::viridis(1), "#3366FF")) +
         xlab("Probability Threshold") +
-        ylab(measure$id)
+        ylab(measure$id) +
+        apply_theme(list(
+          scale_color_viridis_d(),
+          theme_mlr3()
+        ))
     },
 
     stopf("Unknown plot type '%s'", type)
