@@ -35,6 +35,8 @@
 #'
 #' @return [ggplot2::ggplot()] object.
 #'
+#' @template section_theme
+#'
 #' @references
 #' `r format_bib("precrec")`
 #'
@@ -86,26 +88,38 @@ autoplot.ResampleResult = function(object, # nolint
     "boxplot" = {
       ggplot(object, measure = measure, aes_string(y = "performance")) +
         geom_boxplot(...) +
-        ylab(measure$id)
+        ylab(measure$id) +
+        apply_theme(list(theme_mlr3())) +
+        theme(axis.text.x.bottom = element_blank())
     },
 
     "histogram" = {
       ggplot(object, measure = measure, aes_string(x = "performance")) +
-        geom_histogram(...) +
-        xlab(measure$id)
+        geom_histogram(fill = "white", color = "black", ...) +
+        xlab(measure$id) +
+        ylab("Count") +
+        apply_theme(list(theme_mlr3()))
     },
 
     "roc" = {
-      plot_precrec(object, curvetype = "ROC", ...)
+      plot_precrec(object, curvetype = "ROC", ...) +
+        apply_theme(list(
+          scale_color_viridis_d("Learner", end = 0.8),
+          theme_mlr3(legend = "none")
+        )) +
+        theme(plot.title = element_blank())
     },
 
     "prc" = {
-      plot_precrec(object, curvetype = "PRC", ...)
+      plot_precrec(object, curvetype = "PRC", ...) +
+        apply_theme(list(
+          scale_color_viridis_d("Learner", end = 0.8),
+          theme_mlr3(legend = "none")
+        )) +
+        theme(plot.title = element_blank())
     },
 
-    "prediction" = plot_learner_prediction_resample_result(
-      object,
-      predict_sets, ...),
+    "prediction" = plot_learner_prediction_resample_result(object, predict_sets, ...),
 
     stopf("Unknown plot type '%s'", type)
   )
@@ -161,7 +175,7 @@ plot_learner_prediction_resample_result = function(object, # nolint
 
   # facets for multiple resampling iterations
   if (length(learners) > 1L) {
-    iters = object$resampling$data$iteration
+    iters = seq_len(object$resampling$iters)
     facet_labels = paste(object$resampling$id, iters)
     names(facet_labels) = iters
     folds_facet = facet_wrap(".id", labeller = as_labeller(facet_labels))
@@ -190,6 +204,7 @@ plot_learner_prediction_resample_result = function(object, # nolint
         values = c(train = 16, test = 15, both = 17),
         name = "Set") +
       labs(color = "Set") +
+      scale_color_viridis_d() +
       folds_facet
 
     # 2d plot regr + classif
@@ -198,21 +213,17 @@ plot_learner_prediction_resample_result = function(object, # nolint
       # classif, probs
       raster_aes = aes_string(fill = "response", alpha = ".prob.response")
       scale_alpha = scale_alpha_continuous(name = "Prob.")
-      scale_fill = NULL
+      scale_fill = scale_fill_viridis_d("Learner", end = 0.8)
     } else if (task_type == "classif" && learners[[1L]]$predict_type == "response") {
       # classif, no probs
       raster_aes = aes_string(fill = "response")
       scale_alpha = NULL
-      scale_fill = NULL
+      scale_fill = scale_fill_viridis_d("Learner", end = 0.8)
     } else {
       # regr
       raster_aes = aes_string(fill = "response")
       scale_alpha = NULL
-      # manual values for rev(RColorBrewer::brewer.pal(11, "Spectral"))
-      scale_fill = scale_fill_gradientn(colours = c(
-        "#5E4FA2", "#3288BD",
-        "#66C2A5", "#ABDDA4", "#E6F598", "#FFFFBF", "#FEE08B", "#FDAE61",
-        "#F46D43", "#D53E4F", "#9E0142"))
+      scale_fill = scale_fill_viridis_c("Learner", end = 0.8)
     }
 
     g = ggplot(grid, aes_string(features[1L], features[2L])) +
@@ -225,7 +236,10 @@ plot_learner_prediction_resample_result = function(object, # nolint
         values = c(train = 21, test = 22, both = 23),
         name = "Set") +
       scale_alpha +
-      scale_fill +
+      apply_theme(list(
+        scale_fill,
+        theme_mlr3(legend = "right")
+      )) +
       labs(fill = "Response") +
       folds_facet
   }
